@@ -17,8 +17,8 @@ class DFAs
     friend std::ostream &operator<<(std::ostream &out, DFAs const &dfas);
 
     public:
-        typedef std::pair<std::string, DFA *> Pair;
-        typedef std::vector<Pair> DFAInfo;
+        using Pair = std::pair<std::string, DFA *>;
+        using DFAInfo = std::vector<Pair>;
 
     private:
         DFAInfo d_dfa;
