@@ -4,8 +4,9 @@ void Generator::baseIncludes(ostream &out) const
 {
     bool interactive = d_options.interactive();
     bool caseSensitive = d_options.caseSensitive();
+    string const &pre = d_options.baseclassPreinclude();
 
-    if (interactive || not caseSensitive)
+    if (interactive or not caseSensitive or not pre.empty())
         key(out);
 
     if (interactive)
@@ -14,6 +15,14 @@ void Generator::baseIncludes(ostream &out) const
     if (not caseSensitive)
         out << "#include <cctype>\n";
 
+    if (not pre.empty())
+    {
+        bool abs = pre.front() == '<';
+       
+        out << "#include " << 
+               (abs ? "" : "\"") << pre << (abs ? "\n" : "\"\n");
+    }
+
     if (!d_debug)
         return;
 
