@@ -26,23 +26,10 @@ R"(
             void reRead(size_t ch);         // push back 'ch' (if < 0x100)
                                             // push back str from idx 'fmIdx'
             void reRead(std::string const &str, size_t fmIdx);
-            size_t lineNr() const
-            {
-                return d_lineNr;
-            }
-            size_t nPending() const
-            {
-                return d_deque.size();
-            }
-            void setPending(size_t size)
-            {
-                d_deque.erase(d_deque.begin(), d_deque.end() - size);
-            }
-            void close()                    // force closing the stream
-            {
-                delete d_in;
-                d_in = 0;                   // switchStreams also closes
-            }
+            size_t lineNr() const;
+            size_t nPending() const;
+            void setPending(size_t size);
+            void close();                   // force closing the stream
 
         private:
             size_t next();                  // obtain the next character
@@ -50,7 +37,7 @@ R"(
 
 protected:
 )";     
-// >>>> R"( section ends <<<<
+// >>>> R"(...)" section ends <<<<
 
 }
 
