@@ -5,8 +5,8 @@ void Generator::lexSource() const
     ifstream in;
     ofstream out;
 
-    Errno::open(in,  d_options.lexSkeleton());
-    Errno::open(out, d_options.lexSourcePath());
+    Exception::open(in,  d_options.lexSkeleton());
+    Exception::open(out, d_options.lexSourcePath());
 
     filter(in, out);
 }
