@@ -1,9 +1,9 @@
 #include "options.ih"
 
-void Options::setFilenames()
+void Options::setFilenames(TextType textType)
 {
     if (d_filenames.size())
         emsg << "%filenames multiply specified" << endl;
     else
-        d_filenames = undelimit(*d_matched);
+        d_filenames = textOf(textType);
 }
