@@ -1,6 +1,6 @@
 #include "parser.ih"
 
-Pattern Parser::boln()
+FPattern Parser::boln()
 {
     if (d_tokenCount <= 1)      
         d_boln = true;
