@@ -5,7 +5,7 @@
 
 #include "../charclass/charclass.h"
 #include "../interval/interval.h"
-#include "../pattern/pattern.h"
+#include "../fpattern/fpattern.h"
 #include "../flextypes/flextypes.h"
 
 #endif
