@@ -14,7 +14,13 @@ void Ranges::determineSubsets()
     while (begin != end)
     {
         size_t *last = find_if(begin, end, 
-                                   bind2nd(not_equal_to<size_t>(), *begin));
+            [&](size_t value)
+            {
+                return value != *begin;
+            }
+        );
+        // bind2nd(not_equal_to<size_t>(), *begin));
+
         fill(begin, last, range++);
         begin = last;
     }
