@@ -12,7 +12,12 @@ ostream &operator<<(ostream &out, Ranges const &rangesObj)
     while (begin != end)
     {
         size_t *last = find_if(begin, end, 
-                                   bind2nd(not_equal_to<size_t>(), *begin));
+            [&](size_t value)
+            {
+                return value != *begin;
+            }
+        );
+        //bind2nd(not_equal_to<size_t>(), *begin));
 
         out << setw(2) << range++ << ": ";
         Ranges::outChar(out, begin - ranges);
