@@ -10,7 +10,13 @@ void Ranges::subsetCount()
     {
         ++d_nRanges;
         size_t *last = find_if(begin, end, 
-                                   bind2nd(not_equal_to<size_t>(), *begin));
+            [&](size_t value)
+            {
+                return value != *begin;
+            }
+        );
+        // bind2nd(not_equal_to<size_t>(), *begin));
+
         begin = last;
     }
 }
