@@ -1,6 +1,6 @@
 #include "rules.ih"
 
-void Rules::add(bool bol, Pattern const &pattern, Block const &block,
+void Rules::add(bool bol, FPattern const &pattern, Block const &block,
                 RuleType type) 
 {
     size_t ruleIdx = d_rules.size();        // the index of the rule to add
