@@ -13,7 +13,7 @@
 
 class States;
 class Block;
-class Pattern;
+class FPattern;
 
 class Rules: public FlexTypes
 {
@@ -43,7 +43,7 @@ class Rules: public FlexTypes
         using rule_const_iterator = std::vector<Rule>::const_iterator;
 
         Rules(States &states);
-        void add(bool bol, Pattern const &pattern, Block const &block,
+        void add(bool bol, FPattern const &pattern, Block const &block,
                 RuleType type);
 
         Rule const &operator[](size_t idx) const;
