@@ -5,12 +5,12 @@ int Scanner::handleCharAfterBlanks()
     redo(1);
 
     if (d_inCharClass)
-        return Parser::CHAR;
+        return Tokens::CHAR;
 
     if (d_inBlock)
         return ' ';
 
     d_inBlock = true;
     d_caseSensitive = true;
-    return Parser::BLOCK;
+    return Tokens::BLOCK;
 }
