@@ -9,6 +9,6 @@ int Scanner::handleOpenBracket()
 
         d_inCharClass = true;
     }
-    return Parser::CC_START;
+    return Tokens::CC_START;
 }
 
