@@ -13,8 +13,9 @@ void Scanner::maybeSwitchStream()
                     != string::npos;
 
     if (not isComment)
-        isComment = fs::exists(text);               // the file must exist
-                                                    // or //incl. is comment
+        isComment = not fs::exists(text);           // is the file does not
+                                                    // exist  //incl. is 
+                                                    // considered comment
     if (isComment)
     {
         wmsg << '`' << matched() << "' considered comment" << endl;
