@@ -1,6 +1,6 @@
 #include "scanner.ih"
 
-void Scanner::push(StartCondition__ next)
+void Scanner::push(StartCondition_ next)
 {
     d_scStack.push(next);
     begin(next);
