@@ -112,7 +112,7 @@ void \@Base::toCwd() const
 
     error_code ec;
     current_path(d_cwd, ec);
-};
+}
 
 // static
 std::string \@Base::chgWorkingDir(std::string const &name)     // any name
@@ -274,7 +274,8 @@ $insert 4 debug "MATCH"
 
     setMatchedSize(finalPtr->length);
 
-    d_atBOL = d_matched.back() == '\n';
+                                // size check needed since g++-15
+    d_atBOL = d_matched.size() > 0 and d_matched.back() == '\n';
 
 $insert 4 debug "match buffer contains `" << d_matched << "'"
 
