@@ -11,7 +11,8 @@ class StateData
     size_t d_next2;
 
     public:
-        StateData(size_t next1, size_t next2);
+        StateData(size_t next1, size_t next2);                  // 1
+
         virtual ~StateData();
 
         StateData *dup() const;
