@@ -3,7 +3,7 @@
 States::Pair States::next2()
 {
     Pair ret {next(), next()};
-    d_state[ret.second] = State::factory(State::FINAL, 0, 0);
+    d_state[ret.second] = State(FINAL, 0, 0);
 
     return ret;
 }
